function handleValueChange() {
    var initialValue = Number(Widget.props.value); // Use props.value for initial value
    Widget.Widgets.slider1.$element[0].style.setProperty("--end", (100 - getSliderPercentage(initialValue)) + '%');
    updateSteps();
    configureDiscreteSlider();
    updateLabelVisibility();
}
function handleStepValueChange() {
    Widget.Widgets.slider1.step = Widget.props.step_value;
    updateSteps();
    configureDiscreteSlider();
    updateLabelVisibility();
}
function handleRequiredChange() {
    Widget.Widgets.composite.required = Widget.props.required;
}
Widget.onPropertyChange = function (propname, newvalue, oldvalue) {
    switch (propname) {
        case 'prop-value':
        case 'prop-min_value':
        case 'prop-max_value':
            handleValueChange();
            break;
        case 'prop-step_value':
            handleStepValueChange();
            break;
        case 'prop-required':
            handleRequiredChange();
            break;
    }
};
Widget.onReady = function () {
    Widget.Widgets.container1.class += ' filled-slider discrete-slider';
    handleValueChange();
    handleRequiredChange();
    configureDiscreteSlider();
    handleStepValueChange();
    updateSteps();
    activeSliderElement();
    updateLabelVisibility(); // Update label visibility based on initial value
};
function activeSliderElement() {
    var activeSlider = Widget.Widgets.slider1.$element[0]; // Get the slider element
    if (activeSlider) {
        // Create a new div element
        var newDiv = document.createElement('p');
        newDiv.className = 'active-slider'; // Set a class for styling
        // Append the new element to slider container
        activeSlider.appendChild(newDiv);
    }
}
/*
 * Configure the slider for discrete steps.
 */
function configureDiscreteSlider() {
    var slider = Widget.Widgets.slider1; // Slider widget
    var minValue = parseInt(Widget.props.min_value, 10);
    var maxValue = parseInt(Widget.props.max_value, 10);
    var stepValueParam = Widget.props.step_value;
    var initialValue = Number(Widget.props.value); // Use props.value for initial value
    var stepValue = parseInt(stepValueParam, 10);
    if (isNaN(minValue) || isNaN(maxValue) || isNaN(stepValue) || stepValue <= 0) {
        console.error("Invalid min, max, or step values");
        return;
    }
    // Set slider's min, max, and step attributes
    slider.min = minValue;
    slider.max = maxValue;
    slider.step = stepValue;
    // Ensure slider value is within the range
    if (isNaN(initialValue) || initialValue < minValue || initialValue > maxValue) {
        console.error("Slider value is out of range");
        slider.datavalue = minValue; // Default to minValue if the provided value is invalid
    }
    else {
        slider.datavalue = initialValue; // Set the slider to the provided value
    }
    // Set initial position
    Widget.Widgets.slider1.$element[0].style.setProperty("--end", (100 - getSliderPercentage(slider.datavalue)) + '%');
}
/*
 * Update the labels displayed on the slider.
 */
function updateSteps() {
    var slider = Widget.Widgets.slider1;
    var labelContainer = Widget.Widgets.container2;
    if (slider && labelContainer) {
        var minValue = parseInt(slider.min, 10);
        var maxValue = parseInt(slider.max, 10);
        var stepValue = parseInt(slider.step, 10);
        // Calculate the number of steps
        var numSteps = Math.ceil((maxValue - minValue) / stepValue);
        // Clear existing labels
        labelContainer.$element[0].innerHTML = '';
        // Create and position labels for each step
        for (var i = 0; i <= numSteps; i++) {
            var stepLabel = document.createElement('p');
            stepLabel.className = 'step-label';
            var labelValue = minValue + (i * stepValue);
            // Ensure labelValue does not exceed maxValue
            if (labelValue > maxValue)
                break;
            stepLabel.textContent = labelValue;
            // Calculate and set label position
            var leftPosition = Math.round(((labelValue - minValue) / (maxValue - minValue)) * 100 * 100) / 100; // Rounded to two decimal places
            var adjustedPosition = leftPosition - 1;
            stepLabel.style.setProperty('--position', "".concat(adjustedPosition, "%"));
            stepLabel.setAttribute('data-position', adjustedPosition);
            // Append label to the container
            labelContainer.$element[0].appendChild(stepLabel);
        }
        // Set container positioning and add event listener for updating label visibility
        labelContainer.$element[0].style.position = 'relative';
        Widget.Widgets.slider1.$element[0].addEventListener('input', updateLabelVisibility);
        // Initial update of label visibility
        updateLabelVisibility();
    }
}
function updateLabelVisibility() {
    var slider = Widget.Widgets.slider1;
    var labels = Widget.Widgets.container2.$element[0].getElementsByClassName('step-label');
    if (slider) {
        var sliderValue = Number(slider.datavalue); // Get the current slider value
        var minValue_1 = parseInt(slider.min, 10);
        var maxValue_1 = parseInt(slider.max, 10);
        var stepValue_1 = parseInt(slider.step, 10);
        // Calculate the number of steps
        var targets = Array.from({
            length: Math.ceil((maxValue_1 - minValue_1) / stepValue_1) + 1
        }, function (_, i) { return minValue_1 + i * stepValue_1; }).filter(function (value) { return value <= maxValue_1; });
        // Update label states based on slider value and targets
        for (var _i = 0, labels_1 = labels; _i < labels_1.length; _i++) {
            var label = labels_1[_i];
            var labelValue = parseInt(label.textContent, 10);
            // Remove existing classes
            label.classList.remove('hidden', 'inactive', 'active');
            // Determine the label's state based on the slider value
            if (targets.includes(labelValue)) {
                if (labelValue === sliderValue) {
                    label.classList.add('hidden'); // Hide label if it matches the slider value
                }
                else if (labelValue < sliderValue) {
                    label.classList.add('inactive'); // Label is inactive if it is less than the slider value
                }
                else {
                    label.classList.add('active'); // Label is active if it is greater than the slider value
                }
            }
            // Ensure that labels are visible based on their state
            label.style.display = 'block';
        }
    }
}
/*
 * Convert slider value to percentage based on min and max
 */
function getSliderPercentage(value) {
    var slider = Widget.Widgets.slider1;
    var minValue = parseInt(slider.min, 10);
    var maxValue = parseInt(slider.max, 10);
    return ((value - minValue) / (maxValue - minValue)) * 100;
}
/*
 * Handle slider value changes.
 */
Widget.slider1Change = function ($event, widget, newVal, oldVal) {
    var sliderValue = newVal; // Use the new slider value
    widget.$element[0].style.setProperty("--end", (100 - getSliderPercentage(sliderValue)) + '%');
    // Update label visibility on slider change
    updateLabelVisibility();
};
